@@ -75,8 +75,8 @@ class YamllintRule(AnsibleLintRule):
     def matchyaml(self, file: Lintable) -> List["MatchError"]:
         """Return matches found for a specific YAML text."""
         matches: List["MatchError"] = []
-        filtered_matches = []
-        if file.kind == 'role':
+        filtered_matches: List["MatchError"] = []
+        if file.base_kind != 'text/yaml':
             return matches
 
         if YamllintRule.config:
